
// ByteClassLoader.java
// Andrew Davison, July 2007, ad@fivedots.coe.psu.ac.th

/* A class loader that loads the byte codes for the named class
   from a java file object inside store.
*/


import java.util.*;
import javax.tools.*;


public class ByteClassLoader extends ClassLoader
{
  private Map<String, JavaFileObject> store;
     // maps class names to JFOs containing the classes' byte codes


  public ByteClassLoader(Map<String, JavaFileObject> str)
  {
    super( ByteClassLoader.class.getClassLoader() );   // set parent
    store = str;
  }


  protected Class<?> findClass(String name) throws ClassNotFoundException
  {
    JavaFileObject jfo = store.get(name);      // load the java file object
    if (jfo == null)
      throw new ClassNotFoundException(name);

    byte[] bytes = ((ByteArrayJFO)jfo).getByteArray();    // convert to byte codes array
    Class cl = defineClass(name, bytes, 0, bytes.length);     // send byte codes to the JVM
    if (cl == null)
      throw new ClassNotFoundException(name);
    return cl;
  } // end of findClass()


} // end of ByteClassLoader class
