
// ByteJavaFileManager.java	
// Andrew Davison, July 2007, ad@fivedots.coe.psu.ac.th

/* ByteJavaFileManager forwards calls to a standard java file manager. 
   It overrides the getJavaFileForOutput() method for creating a java
   file object for storing compiler output. 
*/

import java.io.*;
import java.util.*;
import javax.tools.*;
import javax.tools.JavaFileObject.Kind;



public class ByteJavaFileManager<M extends JavaFileManager> 
                            extends ForwardingJavaFileManager<M> 
{

   private Map<String, JavaFileObject> store = 
                       new HashMap<String, JavaFileObject>();
     // maps class names to JFOs containing the classes' byte codes
    

  public ByteJavaFileManager(M fileManager, Map<String, JavaFileObject> str) 
  {  super(fileManager); 
     store = str;
  }  // end of ByteJavaFileManager()



  public JavaFileObject getJavaFileForOutput(Location location,
					       String className, Kind kind, FileObject sibling)
	                                                           throws IOException
  /* Create a new Java file object (jfo) which will be used by the compiler to
     store the generated byte codes. Also add a reference to the object to the 
     store so it can be accessed by other parts of the application.
  */
  {
    try {
      JavaFileObject jfo = new ByteArrayJFO(className, kind);
      store.put(className, jfo);
      return jfo;
    }
    catch(Exception e)
    {  System.out.println(e);
       return null;
    }
  } // end of getJavaFileForOutput()


} // end of ByteJavaFileManager class


