
// JCompiler.java
// Andrew Davison, July 2007, ad@fivedots.coe.psu.ac.th

/* Mimic javac.
   Uses the Compiler API and javac compiler.
   Utilizes StandardJavaFileManager, CompilationTask, and
   DiagnosticCollector.
*/


import java.util.*;
import javax.tools.*;
import javax.tools.JavaCompiler.*;


public class JCompiler
{
  private static DiagnosticCollector<JavaFileObject> diagnostics;


  public static void main(String[] args)
  {
    if (args.length < 1) {
      System.out.println("No file name supplied");
      System.exit(1);
    }

    CompilationTask task = makeCompilerTask(args[0]);
            // args[0] is the name of the file to be compiled

    System.out.println("Compiling " + args[0]);
    if (!task.call())  // carry out the compilation
      System.out.println("Compilation failed");

    for (Diagnostic d : diagnostics.getDiagnostics())   // list any problems
      System.out.println(d);
  }  // end of main()  



  private static CompilationTask makeCompilerTask(String fileName)
  // create a compilation task object for compiling fileName
  {
    JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();   
       // access the compiler provided with this JRE
    if (compiler == null) {
      System.out.println("Compiler not found");
      System.exit(1);
    }

    // create a collector for diagnostic messages
    diagnostics = new DiagnosticCollector<JavaFileObject>();

    // obtain the standard manager for file objects
    StandardJavaFileManager fileMan = 
            compiler.getStandardFileManager(diagnostics, null, null);

    // build an iterable list of java file objects representing the supplied file names
    Iterable<? extends JavaFileObject> fileObjs =
           fileMan.getJavaFileObjectsFromStrings( Arrays.asList(fileName) );

    /* create a compilation task using the supplied file manager, diagnostic
       collector, and applied to the specified file objects */

    Iterable<String> options = Arrays.asList( new String[]{"-Xlint:deprecation"} );
    return compiler.getTask(null, fileMan, diagnostics, options, null, fileObjs);

    // return compiler.getTask(null, fileMan, diagnostics, null, null, fileObjs);
                           // out                    // options, annotated classes
                
  }  // end of makeCompilerTask()


} // end of JCompiler class
