
// StringJCompiler.java
// Andrew Davison, July 2007, ad@fivedots.coe.psu.ac.th

/* Compile a Java code string, saving it in a class file. 
   The class name is supplied on the command line.
   Uses the Compiler API and javac compiler.

   Based on an example at:
     http://www.javabeat.net/javabeat/java6/articles/java_6_0_compiler_api_4.php
 */


import java.util.*;
import javax.tools.*;
import javax.tools.JavaCompiler.*;


public class StringJCompiler
{

  private static DiagnosticCollector<JavaFileObject> diagnostics;
       // a collector for diagnostic messages


  public static void main(String[] args) throws Exception
  {
    if (args.length < 1) {
      System.out.println("No class name supplied");
      System.exit(1);
    }

    StringJFO src = makeCode(args[0]);   // create the code for the class name in args[0]

    CompilationTask task = makeCompilerTask(src);

    System.out.println("Compiling " + args[0]);
    if (!task.call())   // carry out the compilation
      System.out.println("Compilation failed");

    for (Diagnostic d : diagnostics.getDiagnostics())    // list any problems
      System.out.println(d);
  }  // end of main()


  private static StringJFO makeCode(String className)
  /* Convert a string into a string java file object with the 
     specified class name. */
  {
    String codeStr = 
        "public class " + className + " {" +
            "public static void main(String[] args){" +
                "System.out.println(\"Hello \" + args[0]);}}";

    StringJFO src = null;
    try {
      src = new StringJFO(className + ".java", codeStr);
    }
    catch (Exception e) 
    {  System.out.println(e); 
       System.exit(1);
    }
    return src;
  } // end of makeCode()



  private static CompilationTask makeCompilerTask(StringJFO src)
  /* Create a compilation operation object for compiling the 
     string java file object, src. The result is saved in a .class file
  */
  {
    JavaCompiler compiler = ToolProvider.getSystemJavaCompiler();
       // access the compiler provided with this JRE
    if (compiler == null) {
      System.out.println("Compiler not found");
      System.exit(1);
    }

    // create a collector for diagnostic messages
    diagnostics = new DiagnosticCollector<JavaFileObject>();

    // create a manager for the java file objects
    StandardJavaFileManager fileMan = 
            compiler.getStandardFileManager(diagnostics, null, null);

    /* create a compilation task using the supplied file manager, diagnostic
       collector, and applied to the string file object (in a list) */
    return compiler.getTask(null, fileMan, diagnostics, null, null,
                                                   Arrays.asList(src));
  }  // end of makeCompilerTask()


}  // end of StringJCompiler class
