
// StringExecutor.java
// Andrew Davison, August 2007, ad@fivedots.coe.psu.ac.th

/* Compile and load a string representing a class, and then
   call it's main() function with a single argument.
   Uses janino's SimpleCompiler which compiles a single 
   "compilation unit" (i.e. the equivalent of the contents
   of a ".java" file).
*/


import java.io.*;
import java.lang.reflect.*;
import org.codehaus.janino.*;


public class StringExecutor
{
  private static final String CLASS_NAME = "Foo";


  public static void main(String[] args) throws Exception
  {
    if (args.length < 1) {
      System.out.println("No argument supplied");
      System.exit(1);
    }

    String codeStr = 
        "public class " + CLASS_NAME + " {" +
            "public static void main(String[] args){" +
                "System.out.println(\"Hello \" + args[0]);}}";

    SimpleCompiler compiler = new SimpleCompiler();
    compiler.cook( new StringReader(codeStr) );

    // get the loaded class
    Class<?> cl = compiler.getClassLoader().loadClass(CLASS_NAME);

    // Invoke the "public static main(String[])" method
    Method mainMeth = cl.getMethod("main", new Class[] { String[].class });
    String[] methArgs = new String[] { args[0] };        // contains one input argument
    mainMeth.invoke(null, new Object[] { methArgs });
  }  // end of main()


} // end of StringExecutor class
